==> estateplat-common-1.2.3-20180425.071908-67-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwHs.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: zx
 * Date: 15-4-1
 * Time: 下午3:55
 * To change this template use File | Settings | File Templates.
 * doc:视图djsj_fwhs
 */
@Table(name = "djsj_fwhs")
public class BdcFwHs {
    @Id
    private String fwHsIndex;//主键
    private String bdcdyh;//不动产单元号
    private String lszd;//隶属宗地
    private String fwbh;//房屋编号
    private String fjh;//房间号
    private String dyh;//单元号
    private String ch;//层号
    private String zl;//坐落
    private Double jyjg;//交易价格
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private String cqly;//产权来源
    private String gyqk;//共有情况
    private Integer fwlx;//房屋类型
    private String fwxz;//房屋性质
    private String ghyt;//规划用途

    private String fw_dcb_index; //房屋调查表主键
    private Double scjzmj;//实测建筑面积
    private Double sctnjzmj;//实测套内建筑面积
    private Double scftjzmj;//实测分摊建筑面积
    private Double ycjzmj;//预测建筑面积
    private Double yctnjzmj;//预测套内建筑面积
    private Double ycftjzmj;//预测分摊建筑面积
    private Double cg;//层高
    private String fw_hst_index;//房屋户室图主键
    private Date dcsj;//调查时间
    private String dcz;//调查者
    private String dcyj;//调查意见
    private String fjsm;//附加说明
    //    private String bdcdyfwlx;//房屋类型
    private String wlcs;//物理层数
    private String dycs;//定义层数
    //    private String blzt;
    private String qlzt;//权利状态
    private String hbfx;//合并方向
    private String hbhs;//合并户数
    private String fcdah;//房产档案号
    private String sxh;//室序号
    private String sfcsbh;//是否从属编号
    private String fwDcbIndex;//主键
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 预测房屋编码
     */
    private String ycfwbm;

    public java.lang.String getLszd() {
        return lszd;
    }

    public void setLszd(java.lang.String lszd) {
        this.lszd = lszd;
    }

    public java.lang.String getFwbh() {
        return fwbh;
    }

    public void setFwbh(java.lang.String fwbh) {
        this.fwbh = fwbh;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public java.lang.String getCqly() {
        return cqly;
    }

    public void setCqly(java.lang.String cqly) {
        this.cqly = cqly;
    }

    public java.lang.String getGyqk() {
        return gyqk;
    }

    public void setGyqk(java.lang.String gyqk) {
        this.gyqk = gyqk;
    }

    public java.lang.Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(java.lang.Integer fwlx) {
        this.fwlx = fwlx;
    }

    public java.lang.String getFwxz() {
        return fwxz;
    }

    public void setFwxz(java.lang.String fwxz) {
        this.fwxz = fwxz;
    }

    public java.lang.String getFw_dcb_index() {
        return fw_dcb_index;
    }

    public void setFw_dcb_index(java.lang.String fw_dcb_index) {
        this.fw_dcb_index = fw_dcb_index;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public Double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(Double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public Double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(Double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public java.lang.String getFw_hst_index() {
        return fw_hst_index;
    }

    public void setFw_hst_index(java.lang.String fw_hst_index) {
        this.fw_hst_index = fw_hst_index;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public java.lang.String getDcz() {
        return dcz;
    }

    public void setDcz(java.lang.String dcz) {
        this.dcz = dcz;
    }

    public java.lang.String getDcyj() {
        return dcyj;
    }

    public void setDcyj(java.lang.String dcyj) {
        this.dcyj = dcyj;
    }

    public java.lang.String getFjsm() {
        return fjsm;
    }

    public void setFjsm(java.lang.String fjsm) {
        this.fjsm = fjsm;
    }

    public java.lang.String getFcdah() {
        return fcdah;
    }

    public void setFcdah(java.lang.String fcdah) {
        this.fcdah = fcdah;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    //    public String getBdcdyfwlx() {
    //        return bdcdyfwlx;
    //    }
    //
    //    public void setBdcdyfwlx(String bdcdyfwlx) {
    //        this.bdcdyfwlx = bdcdyfwlx;
    //    }

    public String getWlcs() {
        return wlcs;
    }

    public void setWlcs(String wlcs) {
        this.wlcs = wlcs;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }


    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public String getHbhs() {
        return hbhs;
    }

    public void setHbhs(String hbhs) {
        this.hbhs = hbhs;
    }

    public String getSxh() {
        return sxh;
    }

    public void setSxh(String sxh) {
        this.sxh = sxh;
    }

    public String getSfcsbh() {
        return sfcsbh;
    }

    public void setSfcsbh(String sfcsbh) {
        this.sfcsbh = sfcsbh;
    }

    public String getFwHsIndex() {
        return fwHsIndex;
    }

    public void setFwHsIndex(String fwHsIndex) {
        this.fwHsIndex = fwHsIndex;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getYcfwbm() {
        return ycfwbm;
    }

    public void setYcfwbm(String ycfwbm) {
        this.ycfwbm = ycfwbm;
    }
}

==> estateplat-common-1.2.4-20220705.020016-1066-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwHs.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: zx
 * Date: 15-4-1
 * Time: 下午3:55
 * To change this template use File | Settings | File Templates.
 * doc:视图djsj_fwhs
 */
@Table(name = "djsj_fwhs")
public class BdcFwHs {
    @Id
    private String fwHsIndex;//主键
    private String bdcdyh;//不动产单元号
    private String lszd;//隶属宗地
    private String fwbh;//房屋编号
    private String fjh;//房间号
    private String dyh;//单元号
    private String ch;//层号
    private String zl;//坐落
    private Double jyjg;//交易价格
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private String cqly;//产权来源
    private String gyqk;//共有情况
    private Integer fwlx;//房屋类型
    private String fwxz;//房屋性质
    private String ghyt;//规划用途

    private String fw_dcb_index; //房屋调查表主键
    private Double scjzmj;//实测建筑面积
    private Double sctnjzmj;//实测套内建筑面积
    private Double scftjzmj;//实测分摊建筑面积
    private Double ycjzmj;//预测建筑面积
    private Double yctnjzmj;//预测套内建筑面积
    private Double ycftjzmj;//预测分摊建筑面积
    private Double cg;//层高
    private String fw_hst_index;//房屋户室图主键
    private Date dcsj;//调查时间
    private String dcz;//调查者
    private String dcyj;//调查意见
    private String fjsm;//附加说明
    //    private String bdcdyfwlx;//房屋类型
    private String wlcs;//物理层数
    private String dycs;//定义层数
    //    private String blzt;
    private String qlzt;//权利状态
    private String hbfx;//合并方向
    private String hbhs;//合并户数
    private String fcdah;//房产档案号
    private String sxh;//室序号
    private String sfcsbh;//是否从属编号
    private String fwDcbIndex;//主键
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 预测房屋编码
     */
    private String ycfwbm;

    /**
     * 房屋编码
     */
    private String fwbm;

    public java.lang.String getLszd() {
        return lszd;
    }

    public void setLszd(java.lang.String lszd) {
        this.lszd = lszd;
    }

    public java.lang.String getFwbh() {
        return fwbh;
    }

    public void setFwbh(java.lang.String fwbh) {
        this.fwbh = fwbh;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public java.lang.String getCqly() {
        return cqly;
    }

    public void setCqly(java.lang.String cqly) {
        this.cqly = cqly;
    }

    public java.lang.String getGyqk() {
        return gyqk;
    }

    public void setGyqk(java.lang.String gyqk) {
        this.gyqk = gyqk;
    }

    public java.lang.Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(java.lang.Integer fwlx) {
        this.fwlx = fwlx;
    }

    public java.lang.String getFwxz() {
        return fwxz;
    }

    public void setFwxz(java.lang.String fwxz) {
        this.fwxz = fwxz;
    }

    public java.lang.String getFw_dcb_index() {
        return fw_dcb_index;
    }

    public void setFw_dcb_index(java.lang.String fw_dcb_index) {
        this.fw_dcb_index = fw_dcb_index;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public Double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(Double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public Double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(Double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public java.lang.String getFw_hst_index() {
        return fw_hst_index;
    }

    public void setFw_hst_index(java.lang.String fw_hst_index) {
        this.fw_hst_index = fw_hst_index;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public java.lang.String getDcz() {
        return dcz;
    }

    public void setDcz(java.lang.String dcz) {
        this.dcz = dcz;
    }

    public java.lang.String getDcyj() {
        return dcyj;
    }

    public void setDcyj(java.lang.String dcyj) {
        this.dcyj = dcyj;
    }

    public java.lang.String getFjsm() {
        return fjsm;
    }

    public void setFjsm(java.lang.String fjsm) {
        this.fjsm = fjsm;
    }

    public java.lang.String getFcdah() {
        return fcdah;
    }

    public void setFcdah(java.lang.String fcdah) {
        this.fcdah = fcdah;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    //    public String getBdcdyfwlx() {
    //        return bdcdyfwlx;
    //    }
    //
    //    public void setBdcdyfwlx(String bdcdyfwlx) {
    //        this.bdcdyfwlx = bdcdyfwlx;
    //    }

    public String getWlcs() {
        return wlcs;
    }

    public void setWlcs(String wlcs) {
        this.wlcs = wlcs;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }


    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public String getHbhs() {
        return hbhs;
    }

    public void setHbhs(String hbhs) {
        this.hbhs = hbhs;
    }

    public String getSxh() {
        return sxh;
    }

    public void setSxh(String sxh) {
        this.sxh = sxh;
    }

    public String getSfcsbh() {
        return sfcsbh;
    }

    public void setSfcsbh(String sfcsbh) {
        this.sfcsbh = sfcsbh;
    }

    public String getFwHsIndex() {
        return fwHsIndex;
    }

    public void setFwHsIndex(String fwHsIndex) {
        this.fwHsIndex = fwHsIndex;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getYcfwbm() {
        return ycfwbm;
    }

    public void setYcfwbm(String ycfwbm) {
        this.ycfwbm = ycfwbm;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }
}
